<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    wp_die();
}

class SDOP_RSS
{

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Constructor
     *
     * @since     1.0.0
     */

    public function __construct()
    {
        add_action('rss2_item', [$this, 'sdop_add_thumbnail_to_rss']);
        add_action('rss2_item', [$this, 'sdop_add_section_rss']);
        add_action('rss2_ns', [$this, 'sdop_add_szn_namespace']);
    }

    /**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     * @since     1.0.0
     *
     */
    public static function get_instance()
    {
        // If the single instance hasn't been set, set it now.
        if (null == self::$instance) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    /**
     * ADD an image to the RSS Feed
     */
    public function sdop_add_thumbnail_to_rss()
    {
        global $post;
        if (has_post_thumbnail($post->ID)):
            $content = get_the_post_thumbnail_url($post->ID, 'medium');
            $bytes = filesize(get_attached_file(get_post_thumbnail_id()));
            echo '<enclosure url="' . $content . '" length="' . $bytes . '" type="image/jpg"/>';
        endif;
    }

    /**
     * ADD Seznam URL to the Feed
     */
    public function sdop_add_szn_namespace()
    {
        echo 'xmlns:szn="https://www.seznam.cz"';
    }

    /**
     * ADD Categories to the Feed
     */
    public function sdop_add_section_rss()
    {
        $categories_allowed = get_option('sdop-rss-settings', '1');
        if (!empty($categories_allowed)) {
            global $post;
            $categories = get_the_category($post->ID);
            if (is_array($categories) && !empty($categories)) :
                foreach ($categories as $category) {
                    echo "\r\n<szn:section><![CDATA[{$category->name}]]></szn:section>";
                }
            endif;
        }
    }
}